From ec1f867385dc5fe66fd5cefefeca3e8c5d60a70b Mon Sep 17 00:00:00 2001
From: Justin Pryzby <pryzbyj@telsasoft.com>
Date: Thu, 5 Mar 2020 19:48:08 -0600
Subject: [PATCH v10 3/5] Capitalize consistently

---
 src/backend/commands/cluster.c | 8 ++++----
 src/backend/commands/vacuum.c  | 6 +++---
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/src/backend/commands/cluster.c b/src/backend/commands/cluster.c
index 0e13c5192e..dcede5e908 100644
--- a/src/backend/commands/cluster.c
+++ b/src/backend/commands/cluster.c
@@ -103,11 +103,11 @@ void
 cluster(ClusterStmt *stmt, bool isTopLevel)
 {
 	/* Oid of tablespace to use for clustered relation. */
-	Oid tableSpaceOid = InvalidOid;
+	Oid tablespaceOid = InvalidOid;
 
 	/* Select tablespace Oid to use. */
 	if (stmt->tablespacename)
-		tableSpaceOid = get_tablespace_oid(stmt->tablespacename, false);
+		tablespaceOid = get_tablespace_oid(stmt->tablespacename, false);
 
 	if (stmt->relation != NULL)
 	{
@@ -190,7 +190,7 @@ cluster(ClusterStmt *stmt, bool isTopLevel)
 		table_close(rel, NoLock);
 
 		/* Do the job. */
-		cluster_rel(tableOid, indexOid, tableSpaceOid, stmt->options);
+		cluster_rel(tableOid, indexOid, tablespaceOid, stmt->options);
 	}
 	else
 	{
@@ -238,7 +238,7 @@ cluster(ClusterStmt *stmt, bool isTopLevel)
 			/* functions in indexes may want a snapshot set */
 			PushActiveSnapshot(GetTransactionSnapshot());
 			/* Do the job. */
-			cluster_rel(rvtc->tableOid, rvtc->indexOid, tableSpaceOid,
+			cluster_rel(rvtc->tableOid, rvtc->indexOid, tablespaceOid,
 						stmt->options | CLUOPT_RECHECK);
 			PopActiveSnapshot();
 			CommitTransactionCommand();
diff --git a/src/backend/commands/vacuum.c b/src/backend/commands/vacuum.c
index cfa64b80fd..1a0ca44da8 100644
--- a/src/backend/commands/vacuum.c
+++ b/src/backend/commands/vacuum.c
@@ -109,7 +109,7 @@ ExecVacuum(ParseState *pstate, VacuumStmt *vacstmt, bool isTopLevel)
 	bool		parallel_option = false;
 	ListCell   *lc;
 
-	Oid tableSpaceOid = InvalidOid; /* Oid of tablespace to use for relations
+	Oid tablespaceOid = InvalidOid; /* Oid of tablespace to use for relations
 									 * store after VACUUM FULL. */
 	/* Set default value */
 	params.index_cleanup = VACOPT_TERNARY_DEFAULT;
@@ -249,13 +249,13 @@ ExecVacuum(ParseState *pstate, VacuumStmt *vacstmt, bool isTopLevel)
 	if (vacstmt->tablespacename)
 	{
 		if (params.options & VACOPT_FULL)
-			tableSpaceOid = get_tablespace_oid(vacstmt->tablespacename, false);
+			tablespaceOid = get_tablespace_oid(vacstmt->tablespacename, false);
 		else
 			ereport(ERROR,
 				(errmsg("incompatible SET TABLESPACE option"),
 				errdetail("You can only use SET TABLESPACE with VACUUM FULL.")));
 	}
-	params.tablespace_oid = tableSpaceOid;
+	params.tablespace_oid = tablespaceOid;
 
 	/* user-invoked vacuum is never "for wraparound" */
 	params.is_wraparound = false;
-- 
2.17.0

